@@ -1,11 +1,10 @@
 import logging
 from datetime import datetime, timedelta
 
-from pykusto.expressions import column_generator as col
-from pykusto.functions import Functions as f
-from pykusto.logger import logger
-from pykusto.query import Query
-from test.test_base import TestBase
+from pykusto import column_generator as col, Functions as f, Query
+# noinspection PyProtectedMember
+from pykusto._src.logger import _logger
+from test.test_base import TestBase, test_logger
 from test.test_base import mock_table as t
 
 
@@ -269,6 +268,26 @@ class TestFunction(TestBase):
                 f.make_datetime(t.numField, t.numField2, t.numField3, t.numField4, t.numField5, t.numField6) > datetime(2019, 7, 23, 5, 29, 15)).render()
         )
 
+    def test_make_string(self):
+        self.assertEqual(
+            " | where (make_string(75, 117, 115, 116, 111)) == \"Kusto\"",
+            Query().where(f.make_string(75, 117, 115, 116, 111) == 'Kusto').render()
+        )
+        self.assertEqual(
+            " | where (make_string(dynamic([75, 117, 115]), 116, 111)) == \"Kusto\"",
+            Query().where(f.make_string([75, 117, 115], 116, 111) == 'Kusto').render()
+        )
+
+    def test_month_of_year(self):
+        self.assertEqual(
+            " | where (monthofyear(dateField)) == 12",
+            Query().where(f.month_of_year(t.dateField) == 12).render()
+        )
+        self.assertEqual(
+            " | where (monthofyear(datetime(2015-12-14 00:00:00.000000))) == 12",
+            Query().where(f.month_of_year(datetime(2015, 12, 14)) == 12).render()
+        )
+
     def test_now(self):
         self.assertEqual(
             " | where dateField < (now())",
@@ -279,6 +298,18 @@ class TestFunction(TestBase):
             Query().where(t.dateField < f.now(timedelta(-3))).render()
         )
 
+    def test_pack_all(self):
+        self.assertEqual(
+            " | extend packed = pack_all()",
+            Query().extend(packed=f.pack_all()).render()
+        )
+
+    def test_pack_dictionary(self):
+        self.assertEqual(
+            ' | extend foo = pack_dictionary("bar", numField, "baz", stringField)',
+            Query().extend(foo=f.pack_dictionary(bar=t.numField, baz=t.stringField)).render()
+        )
+
     def test_parse_json_to_string(self):
         self.assertEqual(
             ' | where (tostring(parse_json(stringField))) contains "ABC"',
@@ -466,16 +497,28 @@ class TestFunction(TestBase):
             Query().where(f.to_bool(t.stringField)).render()
         )
 
+    def test_todatetime(self):
+        self.assertEqual(
+            " | extend foo = todatetime(stringField)",
+            Query().extend(foo=f.to_datetime(t.stringField)).render()
+        )
+
+    def test_todecimal(self):
+        self.assertEqual(
+            " | where (todecimal(stringField)) > 0.2",
+            Query().where(f.to_decimal(t.stringField) > 0.2).render()
+        )
+
     def test_todouble(self):
         self.assertEqual(
             " | where (todouble(stringField)) > 0.2",
             Query().where(f.to_double(t.stringField) > 0.2).render()
         )
-        
-    def test_todecimal(self):
+
+    def test_to_dynamic(self):
         self.assertEqual(
-            " | where (todecimal(stringField)) > 0.2",
-            Query().where(f.to_decimal(t.stringField) > 0.2).render()
+            " | extend dyn = todynamic(stringField)",
+            Query().extend(dyn=f.to_dynamic(t.stringField)).render()
         )
 
     def test_toint(self):
@@ -490,12 +533,6 @@ class TestFunction(TestBase):
             Query().where(f.to_long(t.stringField) > 2222222222).render()
         )
 
-    def test_todatetime(self):
-        self.assertEqual(
-            " | extend foo = todatetime(stringField)",
-            Query().extend(foo=f.to_datetime(t.stringField)).render()
-        )
-
     def test_tolower(self):
         self.assertEqual(
             ' | where (tolower(stringField)) == "foo"',
@@ -507,7 +544,13 @@ class TestFunction(TestBase):
             " | where (toreal(stringField)) > 0.2",
             Query().where(f.to_real(t.stringField) > 0.2).render()
         )
-        
+
+    def test_to_timespan(self):
+        self.assertEqual(
+            " | extend t = totimespan(stringField)",
+            Query().extend(t=f.to_timespan(t.stringField)).render()
+        )
+
     def test_toupper(self):
         self.assertEqual(
             ' | where (toupper(stringField)) == "FOO"',
@@ -520,6 +563,11 @@ class TestFunction(TestBase):
             Query().where(f.to_hex(256) == "100").render()
         )
 
+    def test_trim(self):
+        self.assertEqual(
+            ' | where (trim("--", stringField)) == "text"',
+            Query().where(f.trim("--", t.stringField) == "text").render()
+        )
     # ------------------------------------------------------
     # Aggregation Functions
     # ------------------------------------------------------
@@ -796,7 +844,7 @@ class TestFunction(TestBase):
         )
 
     def test_iff_different_types(self):
-        with self.assertLogs(logger, logging.WARN) as cm:
+        with self.assertLogs(_logger, logging.WARN) as cm:
             self.assertEqual(
                 ' | project foo = iff(dateField > (ago(time(2.0:0:0.0))), time(3.0:0:0.0), "hello")',
                 Query().project(foo=f.iff(t.dateField > f.ago(timedelta(2)), timedelta(3), "hello")).render()
@@ -814,7 +862,7 @@ class TestFunction(TestBase):
         )
 
     def test_iff_ambiguous_type(self):
-        with self.assertLogs(logger, logging.WARN) as cm:
+        with self.assertLogs(test_logger, logging.WARN) as cm:
             self.assertEqual(
                 " | project foo = iff(boolField, time(3.0:0:0.0), foo - bar)",
                 Query().project(foo=f.iff(t.boolField, timedelta(3), col.foo - col.bar)).render()
